{% if resources_page %}
  {% if resources_page.has_previous or resources_page.has_next %}
  <nav aria-label="Page navigation example">
    <ul class="pagination pagination-sm justify-content-center">
      {% if resources_page.has_previous %}
      <li class="page-item"><a class="page-link" href="?page={{ resources_page.previous_page_number }}"><i class="bi bi-arrow-left"></i></a></li>
      {% else %}
      <li class="page-item disabled"><a class="page-link"><i class="bi bi-arrow-left"></i></a></li>
      {% endif %}
      {% if resources_page.has_next %}
      <li class="page-item"><a class="page-link" href="?page={{ resources_page.next_page_number }}"><i class="bi bi-arrow-right"></i></a></li>
      {% else %}
      <li class="page-item disabled"><a class="page-link"><i class="bi bi-arrow-right"></i></a></li>
      {% endif %}
    </ul>
  </nav>
  {% endif %}
{% endif %}