{% if project and collection %}
<nav aria-label="breadcrumb">
    <ol class="breadcrumb">
      <li class="breadcrumb-item"><a href="{% url "nui:index" %}">Projets</a></li>
      <li class="breadcrumb-item"><a href="{% url "nui:collection" project.root_collection.pk %}">{{project.label}}</a></li>
      {% for ancestor in collection.ancestors %}
      {% if ancestor.pk != project.root_collection.pk %}
      <li class="breadcrumb-item">
        <a href="{% url "nui:collection" ancestor.pk %}">
          {{ancestor.title}}
        </a>
      </li>
      {% endif %}
      {% endfor %}
      {% if collection.pk != project.root_collection.pk %}
      <li class="breadcrumb-item">
        <a href="{% url "nui:collection" collection.pk %}">
          {{collection.title}}
        </a>
      </li>
      {% endif %}
    </ol>
</nav>
{% endif %}