# Generated by Django 5.1.7 on 2025-05-23 08:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("annotations", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="annotation",
            name="public",
            field=models.BooleanField(default=False),
        ),
    ]
