# Generated by Django 5.1.7 on 2025-04-30 15:36

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("resources", "0039_alter_project_use_exiftool"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="metadata",
            name="data_type",
        ),
        migrations.RemoveField(
            model_name="resourceclass",
            name="set",
        ),
        migrations.RemoveField(
            model_name="resource",
            name="resource_class",
        ),
        migrations.DeleteModel(
            name="MetadataType",
        ),
        migrations.DeleteModel(
            name="ResourceClass",
        ),
    ]
