# Generated by Django 5.1.7 on 2025-05-14 19:56

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "resources",
            "0040_remove_metadata_data_type_remove_resourceclass_set_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="metadata",
            options={
                "ordering": ["set", "rank", "title"],
                "verbose_name": "meta-donnée",
                "verbose_name_plural": "meta-données",
            },
        ),
        migrations.AlterModelOptions(
            name="metadataresourcevalue",
            options={"ordering": ("metadata",)},
        ),
    ]
