{% load static %}
{% load nui_extras %}
<!DOCTYPE html>
<html lang="en" data-bs-theme="auto">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>JAMA - Browse</title>
    <script src="{% static "nui/bootstrap.bundle.js" %}?v={% jama_version %}"></script>
    <link href="{% static "nui/bootstrap.css" %}?v={% jama_version %}" rel="stylesheet">
    <script src="{% static "nui/unpoly.js" %}?v={% jama_version %}"></script>
    <script src="{% static "nui/openseadragon-bin-5.0.1/openseadragon.js" %}?v={% jama_version %}"></script>
    <link rel="stylesheet" href="{% static "nui/unpoly.css" %}?v={% jama_version %}">
    <link rel="stylesheet" href="{% static "nui/unpoly-bootstrap5.css" %}?v={% jama_version %}">
    <link rel="stylesheet" href="{% static "nui/icons/bootstrap-icons.css" %}?v={% jama_version %}">
    <link rel="stylesheet" href="{% static "nui/app.css" %}?v={% jama_version %}">
</head>
<body>
    <nav class="navbar navbar-expand-lg bg-body-tertiary">
        <div class="container-fluid">
          <a class="navbar-brand" href="{% url "nui:index" %}">
            <i class="bi bi-database-check"></i> Jama
          </a>
          <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
          </button>
          <div class="collapse navbar-collapse" id="navbarSupportedContent">
            <ul class="navbar-nav me-auto mb-2 mb-lg-0">
              <!--
              <li class="nav-item">
                <a class="nav-link" href="#">Home</a>
              </li>
              <li class="nav-item">
                <a class="nav-link" href="#">Link</a>
              </li>
              <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" href="#" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                  Dropdown
                </a>
                <ul class="dropdown-menu">
                  <li><a class="dropdown-item" href="#">Action</a></li>
                  <li><a class="dropdown-item" href="#">Another action</a></li>
                  <li><hr class="dropdown-divider"></li>
                  <li><a class="dropdown-item" href="#">Something else here</a></li>
                </ul>
              </li>
              <li class="nav-item">
                <a class="nav-link disabled" aria-disabled="true">Disabled</a>
              </li>
              -->
            </ul>
            <form class="d-flex" role="search" method="get" action="{% url "nui:search" %}">
              {% csrf_token %}
              <input class="form-control me-2" type="search" name="q" placeholder="titre de ressource ou collection" aria-label="Search"/>
              <button class="btn btn-outline-success" type="submit">Chercher</button>
            </form>
          </div>
        </div>
      </nav>
<main class="container-fluid" style="margin-top:1em;">
{% block content %}{% endblock content %}
</main>
<script src="{% static "nui/app.js" %}?v={% jama_version %}"></script>
</body>
</html>