# Generated by Django 3.2.2 on 2021-10-20 08:44

from django.db import migrations


def fixtures(*args):
    pass  # obsolete fixtures, removed


class Migration(migrations.Migration):
    dependencies = [
        ("resources", "0021_auto_20211007_1748"),
    ]

    operations = [migrations.RunPython(fixtures)]
