# Generated by Django 5.2.5 on 2025-09-09 18:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("resources", "0041_alter_metadata_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="collection",
            name="published_at",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
