/*
@view-transition {
  navigation: auto;
}
*/
.table-data{
    table-layout: fixed;
    width: 100%;
    white-space: nowrap;
  }
.table-data td{
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
.popimagecontainer {
  width: 200px;
  height: 200px;
  overflow: hidden;
  display: flex;
}
.popimageimage {
  max-width: inherit;
  max-height: inherit;
  height: inherit;
  width: inherit;
  object-fit: cover;
}
up-drawer[size=half] up-drawer-box {
  width: 50%;
}
tr.removeRow td{
  text-decoration: line-through solid;
}