up-modal .container,
up-modal .container-fluid,
up-drawer .container,
up-drawer .container-fluid,
up-popup .container,
up-popup .container-fluid {
  padding-left: 0;
  padding-right: 0;
  max-width: none;
}
