{% if project %}
<div class="card" style="margin-bottom:1em;">
    <img src="{{picture}}" class="card-img-top" alt=""/>
    <div class="card-body">
      <h5 class="card-title">{{ project.label }}</h5>
      <p class="card-text">{{ project.description }}</p>
      <a href="{% url "nui:collection" project.root_collection.pk %}" class="btn btn-outline-primary">
        <i class="bi bi-eye"></i>
        Voir
      </a>
    </div>
</div>
{% endif %}